@@ -152,7 +152,7 @@ void improve_contiguity(int n, int dim, int *grouping, SparseMatrix poly_point_m
   }
 
   GV_INFO("ratio (edges among discontiguous regions vs total edges)=%f", (double)nbad / ia[n]);
-  const int flag = stress_model(dim, D, &x, maxit);
+  const int flag = stress_model(dim, D, x, maxit);
 
   assert(!flag);
 
